 #!/bin/bash

# source packages are there : ftp://ftp.doc.cs.univ-paris8.fr/mirrors/ftp.porcupine.org/mirrors/postfix-release/official/postfix-2.6.5.tar.gz
# http://postgrey.schweikert.ch/pub/postgrey-1.32.tar.gz
# based on Hyperion's postfix 2.2.7 buildfile
# Maintainer : Son|c <emmanuel.bailleul@cegetel.net>
#
# Changes in 2.3.4 : added LDAP support
# Changes in 2.4.5 : added SASL support
# Changes in 2.5.0 : postgrey included

soft='postfix'
softversion='2.6.5'
soft2='postgrey'
softversion2='1.32'
packageversion='64.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
srcpkg2="$buildir/$soft2-$softversion2.tar.gz"
src="$buildir/$soft-$softversion"
src2="$buildir/$soft2-$softversion2"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvf $srcpkg
tar -xvf $srcpkg2
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest

export CFLAGS="-O2 -march=$arch -mtune=$cpu" 

cd $src
make makefiles CCARGS="-DHAS_LDAP -DUSE_SASL_AUTH -DUSE_CYRUS_SASL \
-I/usr/include/sasl" AUXLIBS="-lldap -llber -lsasl2"

make

sh ./postfix-install -non-interactive \
install_root=$dest \
readme_directory=/usr/doc/postfix-$softversion/readme \
manpage_directory=/usr/man \
daemon_directory=/usr/sbin

#remove conf files in daemon dir
rm $dest/usr/sbin/*.cf
mv $dest/usr/sbin/postfix-files $dest/etc/postfix/

mkdir $dest/var/spool/postfix/postgrey
cp -a $src2/postgrey_whitelist_clients $dest/etc/postfix
cp -a $src2/postgrey_whitelist_recipients $dest/etc/postfix
cp -a $src2/postgrey $dest/usr/sbin
cp -a $src2/policy-test $dest/usr/sbin
chown root.root $dest/var/spool $dest/etc/postfix/postgrey*
chown -R root.root $dest/usr/sbin
chown -R 96:95 $dest/var/spool/postfix $dest/var/lib/postfix
chown root.root $dest/var/spool/postfix $dest/var/spool/postfix/pid
chown root.95 $dest/usr/sbin/postqueue
chown root.95 $dest/usr/sbin/postdrop
chmod 2755 $dest/usr/sbin/postqueue
chmod 2755 $dest/usr/sbin/postdrop
mv $dest/etc/postfix/aliases $dest/etc/


#Relocate files
(cd $dest/etc/postfix
for file in access bounce.cf.default canonical generic header_checks main.cf main.cf.default \
   master.cf relocated transport virtual postgrey_whitelist_recipients postgrey_whitelist_clients; do
   mv $file $file.new
done)
(cd $dest/etc
mv aliases aliases.new)

( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

mkdir -p $dest/usr/doc/$soft-$softversion/$soft2-$softversion2
cp -a \
  AAAREADME COMPATIBILITY COPYRIGHT HISTORY INSTALL LICENSE PORTING RELEASE_NOTES* README_FILES \
  examples html TLS* US_PATENT_6321267 pflogsumm-conn-delays-dsn-patch \
  implementation-notes IPv6-ChangeLog \
  $dest/usr/doc/$soft-$softversion
cd $src2
cp -a \
  COPYING Changes README README.exim contrib \
  $dest/usr/doc/$soft-$softversion/$soft2-$softversion2
chown -R root.root $dest/usr/doc/$soft-$softversion
rm -f $dest/etc/postfix/LICENSE $dest/etc/postfix/TLS_LICENSE

mkdir -p $dest/install 
cat << "EOF"  > $dest/install/slack-desc
       |-----handy-ruler------------------------------------------------------|
postfix: smtp mail transfer agent
postfix: 
postfix: Postfix is a secure, flexible and powerful SMTP mail transfer agent
postfix: Postfix attempts to be fast,easy to administer, while at the same
postfix: time being sendmail compatible enough to not upset your users.
postfix:
postfix: Postgrey is a Postfix policy server implementing greylisting
postfix:
postfix:
postfix: 
postfix: 
EOF

mkdir -p $dest/etc/rc.d/desc.d
cat << "EOF" > $dest/etc/rc.d/rc.postfix
#!/bin/sh
#
## init script for postfix

postfix_start() {
        if [ -x /usr/sbin/postfix ]; then
                echo -n "Starting postfix MTA:  "
                echo "/usr/sbin/postfix start"
                /usr/sbin/postfix start 2>/dev/null
        fi
}

postfix_stop() {
        /usr/sbin/postfix stop 2>/dev/null
}

postfix_restart() {
        sh $0 stop
	sleep 1
        sh $0 start
}

postfix_reload() {
        /usr/sbin/postfix reload 2>/dev/null
}

case "$1" in
        'start')
                postfix_start
                ;;
        'stop')
                postfix_stop
                ;;
        'restart')
                postfix_restart
                ;;
        'reload')
                postfix_reload
                ;;
        *)
                echo "usage $0 start|stop|restart|reload"
esac
EOF
chmod 644 $dest/etc/rc.d/rc.postfix

cat << "EOF" > $dest/etc/rc.d/rc.postgrey
#!/bin/sh
#
## init script for postgrey

postgrey_start() {
        if [ -x /usr/sbin/postgrey ]; then
                echo -n "Starting postgrey policy server:  "
                echo "/usr/sbin/postgrey -d -i 10030 --user=postfix --group=postfix"
                /usr/sbin/postgrey -d -i 10030 --user=postfix --group=postfix 2>/dev/null
        fi
}

postgrey_stop() {
        killall postgrey 2>/dev/null
}

postgrey_restart() {
        sh $0 stop
	sleep 1
        sh $0 start
}

case "$1" in
        'start')
                postgrey_start
                ;;
        'stop')
                postgrey_stop
                ;;
        'restart')
                postgrey_restart
                ;;
        *)
                echo "usage $0 start|stop|restart"
esac
EOF

echo postgrey:The Postgrey Postfix Policy Server:postgrey>>    $dest/etc/rc.d/desc.d/postgrey.txt
chown -R root.root /etc/rc.d

# create doinst.sh file
echo "config() {
  NEW=\"\$1.new\"
  OLD=\"\$1\"
  # If there's no config file by that name, mv it over:
  if [ ! -r \$OLD ]; then
    mv \$NEW \$OLD
  elif [ \"\`cat \$OLD | md5sum\`\" = \"\`cat \$NEW | md5sum\`\" ]; then # toss the redundant copy
    rm \$NEW
  fi
  # Otherwise, we leave the .new copy for netpkg to consider...
}
config etc/aliases
config etc/postfix/master.cf
config etc/postfix/access
config etc/postfix/bounce.cf.default
config etc/postfix/canonical
config etc/postfix/generic
config etc/postfix/header_checks
config etc/postfix/main.cf
config etc/postfix/main.cf.default
config etc/postfix/relocated
config etc/postfix/transport
config etc/postfix/virtual
config etc/postfix/postgrey_whitelist_clients
config etc/postfix/postgrey_whitelist_recipients
" > $dest/install/doinst.sh

chmod 755 $dest/install/doinst.sh

mkdir -p $dest/usr/src/$soft-$softversion
( cd $buildir
cp -a build-$soft.sh $dest/usr/src/$soft-$softversion/
)

#------------------( Create The *.dep File )

cd $dest
depfinder $dest > $buildir/$package.dep
echo ",perl-IO-Multiplex" >>  $buildir/$package.dep

cd $dest
makepkg -l y -c n $dest.txz

#------------------( Generate the MD5 Check Sum )

cd $buildir
rm -f $package.md5
md5sum $package.txz > $package.md5

# Create source file
echo "ftp://ftp.doc.cs.univ-paris8.fr/mirrors/ftp.porcupine.org/mirrors/postfix-release/official/postfix-2.6.5.tar.gz" > $package.src
echo "http://postgrey.schweikert.ch/pub/postgrey-1.32.tar.gz" >> $package.src
echo "http://download.zenwalk.org/people/emmanuel/postfix-$softversion/build-$soft.sh" >> $package.src

#Private use
echo "extra/n" > $package.cat
